@@ -30,14 +30,13 @@ enum
 {
   PROP_0,
   PROP_WINDOW,
-  PROP_PARENT,
   PROP_NOTE,
   NUM_PROPERTIES
 };
 
 static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
-G_DEFINE_TYPE (BjbNoteView, bjb_note_view, GTK_CLUTTER_TYPE_EMBED)
+G_DEFINE_TYPE (BjbNoteView, bjb_note_view, GTK_TYPE_OVERLAY)
 
 #define GET_PRIVATE(o) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((o), BJB_TYPE_NOTE_VIEW, BjbNoteViewPrivate))
@@ -45,26 +44,19 @@ G_DEFINE_TYPE (BjbNoteView, bjb_note_view, GTK_CLUTTER_TYPE_EMBED)
 struct _BjbNoteViewPrivate {
   /* Data */
   GtkWidget         *window ;
-  GtkWidget         *parent;
   GtkWidget         *view;
   BijiNoteObj       *note ;
 
   /* UI */
-  BijiWebkitEditor *editor;
-  ClutterActor      *embed;
-  ClutterActor      *edit_actor;
+  BijiWebkitEditor  *editor;
   BjbEditorToolbar  *edit_bar;
-  ClutterActor      *edit_bar_actor;
   gboolean           edit_bar_is_sticky;
 
-  ClutterActor      *last_update;
-  ClutterColor      *last_date_bckgrd_clr;
+  GtkWidget         *last_update;
 };
 
-
 static void on_window_closed(GtkWidget *window,gpointer note);
 static gboolean on_note_trashed (BijiNoteObj *note, BjbNoteView *view);
-static void copy_note_color_to_last_updated_background (BjbNoteView *self);
 
 
 static void
@@ -75,7 +67,6 @@ bjb_note_view_disconnect (BjbNoteView *self)
   priv = self->priv;
   g_signal_handlers_disconnect_by_func (priv->window, on_window_closed, priv->note);
   g_signal_handlers_disconnect_by_func (priv->note, on_note_trashed, self);
-  g_signal_handlers_disconnect_by_func (priv->note, copy_note_color_to_last_updated_background, self);
 }
 
 
@@ -88,7 +79,6 @@ bjb_note_view_finalize(GObject *object)
   bjb_note_view_disconnect (self);
 
   g_clear_object (&priv->view);
-  clutter_color_free (priv->last_date_bckgrd_clr);
 
   G_OBJECT_CLASS (bjb_note_view_parent_class)->finalize (object);
 }
@@ -106,9 +96,6 @@ bjb_note_view_get_property (GObject      *object,
     case PROP_WINDOW:
       g_value_set_object (value, self->priv->window);
       break;
-    case PROP_PARENT:
-      g_value_set_object (value, self->priv->parent);
-      break;
     case PROP_NOTE:
       g_value_set_object (value, self->priv->note);
       break;
@@ -131,9 +118,6 @@ bjb_note_view_set_property ( GObject        *object,
     case PROP_WINDOW:
       self->priv->window = g_value_get_object(value);
       break;
-    case PROP_PARENT:
-      self->priv->parent = g_value_get_object (value);
-      break;
     case PROP_NOTE:
       self->priv->note = g_value_get_object(value);
       break;
@@ -149,7 +133,6 @@ bjb_note_view_init (BjbNoteView *self)
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, BJB_TYPE_NOTE_VIEW,
                                             BjbNoteViewPrivate);
 
-  self->priv->last_date_bckgrd_clr = NULL;
 }
 
 static void
@@ -183,65 +166,34 @@ on_note_trashed (BijiNoteObj *note, BjbNoteView *view)
   return TRUE;
 }
 
-static void
-copy_note_color_to_last_updated_background (BjbNoteView *self)
-{
-  BjbNoteViewPrivate *priv = self->priv;
-  GdkRGBA note_color;
 
-  if (biji_note_obj_get_rgba (priv->note, &note_color))
-  {
-    if (priv->last_date_bckgrd_clr)
-      clutter_color_free (priv->last_date_bckgrd_clr);
-
-    priv->last_date_bckgrd_clr = clutter_color_new (255 * note_color.red,
-                                                    255 * note_color.green,
-                                                    255 * note_color.blue,
-                                                    255);
-
-    clutter_actor_set_background_color (priv->last_update, priv->last_date_bckgrd_clr);
-  }
-}
 
 /* Number of days since last updated
  * Instead we might want to play with a func to have a date
  * Also this might be integrated in text view */
-ClutterActor *
+GtkWidget *
 bjb_note_view_last_updated_actor_new (BjbNoteView *self)
 {
-  ClutterActor *result, *text;
-  ClutterLayoutManager *layout;
-  ClutterColor last_up_col = {122,122,122,255};
+  GtkWidget *ret;
+  gchar *str;
 
-  gchar *last_updated_str;
 
-  result = clutter_actor_new ();
-  layout = clutter_box_layout_new ();
-  clutter_actor_set_layout_manager (result, layout);
+  /* Translators: %s is the note last recency description.
+   * Last updated is placed as in left to right language
+   * right to left languages might move %s
+   *         '%s <b>Last Updated</b>'
+   */
+  str = g_strdup_printf (_("<b>Last updated</b> %s"),
+		         biji_note_obj_get_last_change_date_string (self->priv->note));
+                       // "<span background='white'><b>Last updated</b> %s</span>
+  ret = gtk_label_new (str);
+  gtk_label_set_use_markup (GTK_LABEL (ret), TRUE);
 
-  text = clutter_text_new ();
-  /* "Last updated" precedes the note last updated date */
-
-  clutter_text_set_text (CLUTTER_TEXT (text), _("Last updated"));
-  clutter_text_set_font_name (CLUTTER_TEXT (text), "Arial 12px");
-  clutter_text_set_color (CLUTTER_TEXT (text), &last_up_col );
-  clutter_actor_add_child (result, text);
-
-  text = clutter_text_new ();
-  clutter_text_set_text (CLUTTER_TEXT (text), "      ");
-  clutter_actor_add_child (result, text);
-
-  text = clutter_text_new ();
-  last_updated_str = biji_note_obj_get_last_change_date_string (
-                                                      self->priv->note);
-  clutter_text_set_text (CLUTTER_TEXT (text), last_updated_str);
-  clutter_text_set_font_name (CLUTTER_TEXT (text), "Arial 12px");
-  clutter_actor_add_child (result, text);
-
-  clutter_actor_show (result);
-  return result ;
+  g_free (str);
+  return ret;
 }
 
+
 static void
 bjb_note_view_constructed (GObject *obj)
 {
@@ -249,9 +201,6 @@ bjb_note_view_constructed (GObject *obj)
   BjbNoteViewPrivate     *priv = self->priv;
   BjbSettings            *settings;
   GtkWidget              *scroll;
-  ClutterActor           *text_actor, *overlay;
-  ClutterConstraint      *constraint;
-  ClutterLayoutManager   *full, *bin;
   gchar                  *default_font;
   GdkRGBA                 color;
 
@@ -272,24 +221,6 @@ bjb_note_view_constructed (GObject *obj)
   g_signal_connect(priv->window,"destroy",
                    G_CALLBACK(on_window_closed), priv->note);
 
-  /* Start packing ui */
-  gtk_container_add (GTK_CONTAINER (priv->parent), GTK_WIDGET (self));
-  priv->embed = gtk_clutter_embed_get_stage (GTK_CLUTTER_EMBED (self));
-
-  full = clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_CENTER,
-                                 CLUTTER_BIN_ALIGNMENT_CENTER);
-
-  clutter_actor_set_layout_manager (priv->embed, full);
-
-  /* Overlay contains Text and EditToolbar */
-  overlay = clutter_actor_new ();
-  bin = clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_CENTER,
-                                CLUTTER_BIN_ALIGNMENT_CENTER);
-
-  clutter_actor_set_layout_manager (overlay,bin);
-  clutter_actor_add_child (priv->embed, overlay);
-  clutter_actor_set_x_expand (overlay,TRUE);
-  clutter_actor_set_y_expand (overlay,TRUE);
 
   /* Text Editor (WebKitMainView) */
   scroll = gtk_scrolled_window_new (NULL,NULL);
@@ -298,22 +229,14 @@ bjb_note_view_constructed (GObject *obj)
   gtk_widget_set_hexpand (scroll, TRUE);
   gtk_widget_set_vexpand (scroll, TRUE);
 
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
-                                       GTK_SHADOW_IN);
-
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
                                   GTK_POLICY_NEVER,
                                   GTK_POLICY_AUTOMATIC);
 
   gtk_container_add (GTK_CONTAINER (scroll), GTK_WIDGET(priv->view));
+  gtk_container_add (GTK_CONTAINER (self), scroll);
   gtk_widget_show (GTK_WIDGET (priv->view));
 
-  text_actor = gtk_clutter_actor_new_with_contents (scroll);
-  clutter_actor_add_child(overlay,text_actor);
-
-  clutter_actor_set_x_expand(text_actor,TRUE);
-  clutter_actor_set_y_expand(text_actor,TRUE);
-
   /* Apply the gsettings font */
 
   if (bjb_settings_use_system_font (settings))
@@ -337,32 +260,23 @@ bjb_note_view_constructed (GObject *obj)
       biji_note_obj_set_rgba (priv->note, &color);
   }
 
-  /* Edition Toolbar */
-  priv->edit_bar = bjb_editor_toolbar_new (overlay, self, priv->note);
-  priv->edit_bar_actor = bjb_editor_toolbar_get_actor (priv->edit_bar);
-  clutter_actor_add_child (priv->embed, priv->edit_bar_actor);
+  /* Edition Toolbar for text selection */
+  priv->edit_bar = bjb_editor_toolbar_new (self, priv->note);
 
   /* Last updated row */
   priv->last_update = bjb_note_view_last_updated_actor_new (self);
-  clutter_actor_add_child (priv->embed,priv->last_update);
-
-  constraint = clutter_align_constraint_new (priv->embed,CLUTTER_ALIGN_X_AXIS,0.05);
-  clutter_actor_add_constraint (priv->last_update, constraint);
-
-  constraint = clutter_align_constraint_new (priv->embed,CLUTTER_ALIGN_Y_AXIS,0.95);
-  clutter_actor_add_constraint (priv->last_update, constraint);
-
-  copy_note_color_to_last_updated_background (self);
-  g_signal_connect_swapped (priv->note, "color-changed",
-                            G_CALLBACK (copy_note_color_to_last_updated_background), self);
+  gtk_widget_set_halign (priv->last_update, GTK_ALIGN_START);
+  gtk_widget_set_margin_start (priv->last_update, 50);
+  gtk_widget_set_valign (priv->last_update, GTK_ALIGN_END);
+  gtk_widget_set_margin_bottom (priv->last_update, 50);
+  gtk_overlay_add_overlay (GTK_OVERLAY (self), priv->last_update);
 }
 
 BjbNoteView *
-bjb_note_view_new (GtkWidget *win, GtkWidget *parent, BijiNoteObj* note)
+bjb_note_view_new (GtkWidget *win, BijiNoteObj* note)
 {
   return g_object_new (BJB_TYPE_NOTE_VIEW,
                        "window",win,
-                       "parent", parent,
                        "note",note,
                        NULL);
 }
@@ -389,16 +303,6 @@ bjb_note_view_class_init (BjbNoteViewClass *klass)
 
   g_object_class_install_property (object_class,PROP_WINDOW,properties[PROP_WINDOW]);
 
-  properties[PROP_PARENT] = g_param_spec_object ("parent",
-                                                 "Parent Widget",
-                                                 "Widget to pack in",
-                                                 GTK_TYPE_WIDGET,
-                                                 G_PARAM_READWRITE |
-                                                 G_PARAM_CONSTRUCT |
-                                                 G_PARAM_STATIC_STRINGS);
-
-  g_object_class_install_property (object_class,PROP_PARENT,properties[PROP_PARENT]);
-
   properties[PROP_NOTE] = g_param_spec_object ("note",
                                                "Note",
                                                "Note",
